@@ -1,5 +1,17 @@
 var NAVTREEINDEX7 =
 {
+"structpw__client__methods.html#a7af9e64e81ebc0b3a7d726ff98e0dd84":[10,0,22,2],
+"structpw__client__methods.html#a898d61fc799b5c09421365854020b357":[10,0,22,5],
+"structpw__client__methods.html#ad5cf20929a275ce91d7fdbbb80e70be3":[10,0,22,0],
+"structpw__context__events.html":[10,0,24],
+"structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d":[10,0,24,3],
+"structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e":[10,0,24,1],
+"structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0":[10,0,24,4],
+"structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87":[10,0,24,2],
+"structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c":[10,0,24,5],
+"structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[10,0,24,0],
+"structpw__control__events.html":[10,0,26],
+"structpw__control__events.html#a2cda9616fd4aa65d7cc2f8dc6efe69dc":[10,0,26,3],
 "structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,0,26,4],
 "structpw__control__events.html#a4e2a4c85f61336fb837a43c931b7c5fa":[10,0,26,1],
 "structpw__control__events.html#ad23091c8931adf9aa85564b31e2d9ca8":[10,0,26,0],
@@ -237,17 +249,5 @@ var NAVTREEINDEX7 =
 "structpw__module__methods.html#ac20cd689bc54dcab9452e65c58fc5da3":[10,0,77,1],
 "structpw__module__methods.html#ace8dfde4c073903664ba703b575f6e01":[10,0,77,0],
 "structpw__node__events.html":[10,0,78],
-"structpw__node__events.html#a07c012e13056aed56de654a44590df89":[10,0,78,1],
-"structpw__node__events.html#a37faf21db57a7e95999db521fb1cbcab":[10,0,78,2],
-"structpw__node__events.html#a9a6cdaf300007bc554b0c0b6bdbf5ccd":[10,0,78,0],
-"structpw__node__info.html":[10,0,79],
-"structpw__node__info.html#a125f4d8851630b989c86fc0ebc83fba0":[10,0,79,10],
-"structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e":[10,0,79,3],
-"structpw__node__info.html#a48075df9117cf8e55b474c8d2d445a1d":[10,0,79,1],
-"structpw__node__info.html#a737754b76140ca4751f2cd68667ffaa2":[10,0,79,2],
-"structpw__node__info.html#a88bcfe3c9dbce8c5c6ac7b663e4db009":[10,0,79,0],
-"structpw__node__info.html#aa2bd90f2d1c5f570eac18709b2acc387":[10,0,79,8],
-"structpw__node__info.html#ab5c2457030a463ccdc6ca5291ced856f":[10,0,79,6],
-"structpw__node__info.html#abc111c6b06e8564fd4a03854e109563b":[10,0,79,9],
-"structpw__node__info.html#ac312e1844784e77e412f6bb341814372":[10,0,79,4]
+"structpw__node__events.html#a07c012e13056aed56de654a44590df89":[10,0,78,1]
 };
